@@ -13,6 +13,7 @@ _OPERATORS = {"+", "-", "*", "/", "%", "(", ")"}  # TODO: add divmod
 _DOUBLE_OPERATORS = {"/", "*"}  # // and ** are valid operators too
 _EXP_OPERATORS = {"-", "+"}     # 1e+2, 1e-2
 
+
 def _get_operand(op_str):
     try:
         return int(op_str)
@@ -68,7 +69,9 @@ def _print_result(result, args):
     # TODO: support configurable n_places (aligned printing is not so easy then)
     n_places = 2
     if isinstance(result, Size):
-        if args.unit is not None:
+        if args.human_readable:
+            print(result.human_readable())
+        elif args.unit is not None:
             value = result.convert_to(args.unit)
             if int(value) == value:
                 print("%d %s" % (int(value), args.unit))
@@ -90,7 +93,7 @@ def _print_result(result, args):
 
 def _main():
     ap = ArgumentParser(epilog="Report issues at https://github.com/storaged-project/libbytesize/issues")
-    ap.add_argument("--version", action="version", version="2.4")
+    ap.add_argument("--version", action="version", version="2.6")
     ap.add_argument("-u", "--unit", choices=(b_units + d_units),
                     help="Unit to show the result in")
     ap.add_argument("-b", "-B", dest="unit", const="B",
@@ -103,9 +106,15 @@ def _main():
         ap.add_argument("--" + d_unit,
                         dest="unit", const=d_unit,
                         help="Show result in " + d_unit, action="store_const")
+    ap.add_argument("-H", "--human-readable", dest="human_readable",
+                    help="Show only single 'best' result", action="store_true")
     ap.add_argument(metavar="EXPRESSION_PART", dest="expressions", nargs="+")
 
-    args = ap.parse_args()
+    if not sys.stdin.isatty():
+        stdin = sys.stdin.read().splitlines()
+        args = ap.parse_args(sys.argv[1:] + stdin)
+    else:
+        args = ap.parse_args()
 
     try:
         tokens = _tokenize(" ".join(args.expressions))
